==> cscec5b-fbxt-impl-3.0.0-20201210.100844-37-sources.jar: com/ejianc/business/fbxt/grap/bean/SumGrapDetailEntity.java <==
package com.ejianc.business.fbxt.grap.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 进度台账子表实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fbxt_sum_grap_detail")
public class SumGrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="sum_grap_id")
    private Long sumGrapId; // 主表主键ID
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="commit_user_id")
    private Long commitUserId; // 提交人主键
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="info_id")
    private String infoId; // 清单主键
    @TableField(value="info_code")
    private String infoCode; // 清单编码
    @TableField(value="info_name")
    private String infoName; // 清单名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="price")
    private java.math.BigDecimal price; // 无税单价
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 金额
    @TableField(value="construction")
    private String construction; // 施工部位
    @TableField(value="grap_id")
    private Long grapId; // 进度计量单主键ID
    @TableField(value="grap_detail_id")
    private Long grapDetailId; // 进度计量单子表主键ID
    @TableField(value="parent_id")
    private Long parentId; // parent_id
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="approve_num")
    private java.math.BigDecimal approveNum; // 审核数量
    @TableField(value="approve_mny")
    private java.math.BigDecimal approveMny; // 审批金额
    @TableField(value="detail_index")
    private java.lang.String detailIndex; // 序号


    /**
     * 主表主键ID
     */
    public Long getSumGrapId() {
        return sumGrapId;
    }

    /**
     * 主表主键ID
     */
    public void setSumGrapId(Long sumGrapId) {
        this.sumGrapId = sumGrapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 提交人主键
     */
    public Long getCommitUserId() {
        return commitUserId;
    }

    /**
     * 提交人主键
     */
    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    /**
     * 提交人名称
     */
    public String getCommitUserName() {
        return commitUserName;
    }

    /**
     * 提交人名称
     */
    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 施工部位
     */
    public String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(String construction) {
        this.construction = construction;
    }
    /**
     * 进度计量单主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 进度计量单主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 进度计量单子表主键ID
     */
    public Long getGrapDetailId() {
        return grapDetailId;
    }

    /**
     * 进度计量单子表主键ID
     */
    public void setGrapDetailId(Long grapDetailId) {
        this.grapDetailId = grapDetailId;
    }
    /**
     * parent_id
     */
    public Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Integer getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 审核数量
     */
    public java.math.BigDecimal getApproveNum() {
        return approveNum;
    }

    /**
     * 审核数量
     */
    public void setApproveNum(java.math.BigDecimal approveNum) {
        this.approveNum = approveNum;
    }
    /**
     * 审批金额
     */
    public java.math.BigDecimal getApproveMny() {
        return approveMny;
    }

    /**
     * 审批金额
     */
    public void setApproveMny(java.math.BigDecimal approveMny) {
        this.approveMny = approveMny;
    }
    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }

}

==> cscec5b-fbxt-impl-3.0.1-20251014.091841-203-sources.jar: com/ejianc/business/fbxt/grap/bean/SumGrapDetailEntity.java <==
package com.ejianc.business.fbxt.grap.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 进度台账子表实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fbxt_sum_grap_detail")
public class SumGrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="sum_grap_id")
    private Long sumGrapId; // 主表主键ID
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="commit_user_id")
    private Long commitUserId; // 提交人主键
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="info_id")
    private String infoId; // 清单主键
    @TableField(value="info_code")
    private String infoCode; // 清单编码
    @TableField(value="info_name")
    private String infoName; // 清单名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="price")
    private java.math.BigDecimal price; // 无税单价
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 金额
    @TableField(value="construction")
    private String construction; // 施工部位
    @TableField(value="description")
    private String description; // 进度说明
    @TableField(value="grap_id")
    private Long grapId; // 进度计量单主键ID
    @TableField(value="grap_detail_id")
    private Long grapDetailId; // 进度计量单子表主键ID
    @TableField(value="parent_id")
    private Long parentId; // parent_id
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="approve_num")
    private java.math.BigDecimal approveNum; // 审核数量
    @TableField(value="approve_mny")
    private java.math.BigDecimal approveMny; // 审批金额
    @TableField(value="detail_index")
    private java.lang.String detailIndex; // 序号
    @TableField(value="old_num")
    private java.math.BigDecimal oldNum; // 原始数量


    /**
     * 主表主键ID
     */
    public Long getSumGrapId() {
        return sumGrapId;
    }

    /**
     * 主表主键ID
     */
    public void setSumGrapId(Long sumGrapId) {
        this.sumGrapId = sumGrapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 提交人主键
     */
    public Long getCommitUserId() {
        return commitUserId;
    }

    /**
     * 提交人主键
     */
    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    /**
     * 提交人名称
     */
    public String getCommitUserName() {
        return commitUserName;
    }

    /**
     * 提交人名称
     */
    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 施工部位
     */
    public String getConstruction() {
        return construction;
    }

    /**
     * 施工部位
     */
    public void setConstruction(String construction) {
        this.construction = construction;
    }
    /**
     * 进度说明
     */
    public String getDescription() {
        return description;
    }

    /**
     * 进度说明
     */
    public void setDescription(String description) {
        this.description = description;
    }
    /**
     * 进度计量单主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 进度计量单主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 进度计量单子表主键ID
     */
    public Long getGrapDetailId() {
        return grapDetailId;
    }

    /**
     * 进度计量单子表主键ID
     */
    public void setGrapDetailId(Long grapDetailId) {
        this.grapDetailId = grapDetailId;
    }
    /**
     * parent_id
     */
    public Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Integer getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 审核数量
     */
    public java.math.BigDecimal getApproveNum() {
        return approveNum;
    }

    /**
     * 审核数量
     */
    public void setApproveNum(java.math.BigDecimal approveNum) {
        this.approveNum = approveNum;
    }
    /**
     * 审批金额
     */
    public java.math.BigDecimal getApproveMny() {
        return approveMny;
    }

    /**
     * 审批金额
     */
    public void setApproveMny(java.math.BigDecimal approveMny) {
        this.approveMny = approveMny;
    }
    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * 原始数量
     */
    public java.math.BigDecimal getOldNum() {
        return oldNum;
    }

    /**
     * 原始数量
     */
    public void setOldNum(java.math.BigDecimal oldNum) {
        this.oldNum = oldNum;
    }

}
